CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
59 lines
1.5 KiB
Plaintext
59 lines
1.5 KiB
Plaintext
// Test PGO with multiple kernel launches from a single TU.
|
|
// Verifies that counters from all device functions are collected correctly.
|
|
//
|
|
// REQUIRES: hip, amdgpu
|
|
// RUN: %clang -x hip -fprofile-instr-generate -fcoverage-mapping \
|
|
// RUN: --offload-arch=%amdgpu_arch %s -o %t -L%hip_lib_path -lamdhip64
|
|
// RUN: rm -rf %t.dir && mkdir -p %t.dir
|
|
// RUN: env LLVM_PROFILE_FILE=%t.dir/prof.profraw \
|
|
// RUN: LD_LIBRARY_PATH=%hip_lib_path:$LD_LIBRARY_PATH \
|
|
// RUN: HIP_VISIBLE_DEVICES=0 %run %t
|
|
// RUN: llvm-profdata merge -o %t.profdata %t.dir/
|
|
// RUN: llvm-profdata show --all-functions %t.profdata \
|
|
// RUN: | FileCheck %s --check-prefix=PROF
|
|
//
|
|
// All three kernels plus main should be profiled.
|
|
// PROF-DAG: _Z4fillPii
|
|
// PROF-DAG: _Z5scalePixi
|
|
// PROF-DAG: _Z6negatePin
|
|
// PROF-DAG: main
|
|
// PROF: Total functions: 4
|
|
|
|
#include <hip/hip_runtime.h>
|
|
#include <cstdio>
|
|
|
|
__global__ void fill(int *data, int val) {
|
|
data[threadIdx.x] = val;
|
|
}
|
|
|
|
__global__ void scale(int *data, int factor) {
|
|
data[threadIdx.x] *= factor;
|
|
}
|
|
|
|
__global__ void negate(int *data, int n) {
|
|
int idx = threadIdx.x;
|
|
if (idx < n)
|
|
data[idx] = -data[idx];
|
|
}
|
|
|
|
int main() {
|
|
constexpr int N = 16;
|
|
int h[N];
|
|
int *d;
|
|
(void)hipMalloc(&d, N * sizeof(int));
|
|
|
|
fill<<<1, N>>>(d, 5);
|
|
scale<<<1, N>>>(d, 3);
|
|
negate<<<1, N>>>(d, N);
|
|
|
|
(void)hipMemcpy(h, d, N * sizeof(int), hipMemcpyDeviceToHost);
|
|
(void)hipFree(d);
|
|
|
|
int ok = 1;
|
|
for (int i = 0; i < N; ++i)
|
|
if (h[i] != -15) ok = 0;
|
|
|
|
printf("%s\n", ok ? "PASS" : "FAIL");
|
|
return !ok;
|
|
}
|